mod account_state;
mod locked_item;
mod max_len_btree;
mod max_len_string;
mod max_len_vec;
mod max_serialized_len;
mod signer_pda;
mod timelock;

pub use account_state::AccountState;
pub use locked_item::LockedItem;
pub use max_len_btree::MaxLenBTreeMap;
pub use max_len_string::MaxLenString;
pub use max_len_vec::MaxLenVec;
pub use max_serialized_len::MaxSerializedLen;
pub use signer_pda::{SignerPda, SignerPdaError};
pub use timelock::{Timelock, TimelockError};

#[cfg(any(test, feature = "derive"))]
#[allow(unused_imports)]
#[macro_use]
extern crate agsol_common_derive;
#[cfg(any(test, feature = "derive"))]
pub use agsol_common_derive::*;

const CONTENTS_FULL: &str = "contents full";
type MaxLenResult = Result<(), &'static str>;
